@@ -27,13 +27,23 @@ import (
 	"k8s.io/autoscaler/cluster-autoscaler/cloudprovider"
 	"k8s.io/autoscaler/cluster-autoscaler/config"
 	"k8s.io/autoscaler/cluster-autoscaler/utils/errors"
-	"k8s.io/klog"
-	schedulernodeinfo "k8s.io/kubernetes/pkg/scheduler/nodeinfo"
+	klog "k8s.io/klog/v2"
+	schedulerframework "k8s.io/kubernetes/pkg/scheduler/framework/v1alpha1"
 )
 
 const (
-	// ProviderNameGCE is the name of GCE cloud provider.
-	ProviderNameGCE = "gce"
+	// GPULabel is the label added to nodes with GPU resource.
+	GPULabel = "cloud.google.com/gke-accelerator"
+)
+
+var (
+	availableGPUTypes = map[string]struct{}{
+		"nvidia-tesla-k80":  {},
+		"nvidia-tesla-p100": {},
+		"nvidia-tesla-v100": {},
+		"nvidia-tesla-p4":   {},
+		"nvidia-tesla-t4":   {},
+	}
 )
 
 // GceCloudProvider implements CloudProvider interface.
@@ -56,7 +66,17 @@ func (gce *GceCloudProvider) Cleanup() error {
 
 // Name returns name of the cloud provider.
 func (gce *GceCloudProvider) Name() string {
-	return ProviderNameGCE
+	return cloudprovider.GceProviderName
+}
+
+// GPULabel returns the label added to nodes with GPU resource.
+func (gce *GceCloudProvider) GPULabel() string {
+	return GPULabel
+}
+
+// GetAvailableGPUTypes return all available GPU types cloud provider supports
+func (gce *GceCloudProvider) GetAvailableGPUTypes() map[string]struct{} {
+	return availableGPUTypes
 }
 
 // NodeGroups returns all node groups configured for this cloud provider.
@@ -64,7 +84,7 @@ func (gce *GceCloudProvider) NodeGroups() []cloudprovider.NodeGroup {
 	migs := gce.gceManager.GetMigs()
 	result := make([]cloudprovider.NodeGroup, 0, len(migs))
 	for _, mig := range migs {
-		result = append(result, mig.Config)
+		result = append(result, mig)
 	}
 	return result
 }
@@ -73,6 +93,7 @@ func (gce *GceCloudProvider) NodeGroups() []cloudprovider.NodeGroup {
 func (gce *GceCloudProvider) NodeGroupForNode(node *apiv1.Node) (cloudprovider.NodeGroup, error) {
 	ref, err := GceRefFromProviderId(node.Spec.ProviderID)
 	if err != nil {
+		klog.Errorf("Error extracting node.Spec.ProviderID for node %v: %v", node.Name, err)
 		return nil, err
 	}
 	mig, err := gce.gceManager.GetMigForInstance(ref)
@@ -134,12 +155,16 @@ func (ref GceRef) ToProviderId() string {
 // from provider id which must be in format:
 // gce://<project-id>/<zone>/<name>
 // TODO(piosz): add better check whether the id is correct
-func GceRefFromProviderId(id string) (*GceRef, error) {
+func GceRefFromProviderId(id string) (GceRef, error) {
+	if len(id) == 0 {
+		return GceRef{}, fmt.Errorf("wrong id: expected format gce://<project-id>/<zone>/<name>, got nil")
+	}
+
 	splitted := strings.Split(id[6:], "/")
 	if len(splitted) != 3 {
-		return nil, fmt.Errorf("wrong id: expected format gce://<project-id>/<zone>/<name>, got %v", id)
+		return GceRef{}, fmt.Errorf("wrong id: expected format gce://<project-id>/<zone>/<name>, got %v", id)
 	}
-	return &GceRef{
+	return GceRef{
 		Project: splitted[0],
 		Zone:    splitted[1],
 		Name:    splitted[2],
@@ -248,7 +273,7 @@ func (mig *gceMig) DeleteNodes(nodes []*apiv1.Node) error {
 	if int(size) <= mig.MinSize() {
 		return fmt.Errorf("min size reached, nodes will not be deleted")
 	}
-	refs := make([]*GceRef, 0, len(nodes))
+	refs := make([]GceRef, 0, len(nodes))
 	for _, node := range nodes {
 
 		belongs, err := mig.Belongs(node)
@@ -303,12 +328,12 @@ func (mig *gceMig) Autoprovisioned() bool {
 }
 
 // TemplateNodeInfo returns a node template for this node group.
-func (mig *gceMig) TemplateNodeInfo() (*schedulernodeinfo.NodeInfo, error) {
+func (mig *gceMig) TemplateNodeInfo() (*schedulerframework.NodeInfo, error) {
 	node, err := mig.gceManager.GetMigTemplateNode(mig)
 	if err != nil {
 		return nil, err
 	}
-	nodeInfo := schedulernodeinfo.NewNodeInfo(cloudprovider.BuildKubeProxy(mig.Id()))
+	nodeInfo := schedulerframework.NewNodeInfo(cloudprovider.BuildKubeProxy(mig.Id()))
 	nodeInfo.SetNode(node)
 	return nodeInfo, nil
 }
